package payment

import (
	"cls/pkg/util/page"
	"xorm.io/builder"
)

// PaymentRepository 支付仓储接口
type PaymentRepository interface {
	// Save 保存支付订单
	Save(payment *Payment) error

	// FindByID 根据ID查找支付订单
	FindByID(id uint64) (*Payment, error)

	// FindByOrderNo 根据订单号查找支付订单
	FindByOrderNo(orderNo string) (*Payment, error)

	// FindByTransactionID 根据微信支付订单号查找支付订单
	FindByTransactionID(transactionID string) (*Payment, error)

	// FindByUserID 根据用户ID查找支付订单列表
	FindByUserID(userID uint64, page *page.Page) error

	// FindAll 查询支付订单列表
	FindAll(page *page.Page, conds []builder.Cond) error

	// Update 更新支付订单
	Update(payment *Payment) error

	// Delete 删除支付订单
	Delete(id uint64) error
}
