package modules

import (
	"cls/internal/domain/article"
	"cls/internal/domain/free_trial"
	"cls/internal/domain/purchase"
	"cls/internal/domain/user"
	"cls/pkg/logger"
	"cls/pkg/xorm_engine"
	"go.uber.org/fx"
)

var Module = fx.Module("cls",
	fx.Options(
		AuthModule,
		UserModule,
		ArticleModule,  //文章模块
		PurchaseModule, //购买模块
		FreeTrialModule,
	),
	fx.Options(),
	fx.Invoke(registerModels),
)

func registerModels(engine *xorm_engine.Engine, logger logger.New) {
	log := logger("cls:modules:Module")
	//财联社表
	if err := engine.Cls.Sync2(
		&article.LianV1Article{},
	); err != nil {
		log.Error(err)
	}
	//路诚内建表
	if err := engine.Sync2(
		&user.User{},
		&free_trial.FreeTrial{},
		&purchase.Purchase{},
	); err != nil {
		log.Error(err)
	}
}
